.dashboard .module table th{vertical-align:middle}a{color:#8a8a8a}a:hover{color:#5867dd}::-webkit-scrollbar{width:8px}::-webkit-scrollbar-track{background:transparent}::-webkit-scrollbar-thumb{background:rgba(255,255,255,.3);border-radius:6px}::-webkit-scrollbar-thumb:hover{background:rgba(255,255,255,.4)}.primary{color:#5867dd}form .aligned p.help,form .aligned div.help{clear:initial}.breadcrumbs{white-space:nowrap;overflow:hidden}#left-box__header h1{font-weight:bold}.juss-filter-select{background-color:#eee;border:none !important}.inline-group .tabular tr td.original p{display:none}.popup #container{display:initial;min-width:initial}.popup #content{margin-top:0}#left-box{width:280px;min-width:280px;height:100vh;background:#1e2129;box-sizing:border-box}#left-box__header{height:3.5rem;line-height:3.5rem;padding:0 1rem;display:flex;justify-content:space-between;align-items:center;background-color:rgba(0,0,0,.12)}#left-box__header h1{color:#fff;margin:0}#left-box>ul{margin:0;padding:0;list-style-type:none;padding:1rem 0;box-sizing:border-box;height:calc(100vh - 3.5rem);overflow-y:auto}#left-box>ul>li>a{color:rgba(255,255,255,.95);font-weight:bold;padding:0 1rem;line-height:2.8rem;display:flex;align-items:center;justify-content:space-between;letter-spacing:2px}#left-box>ul>li>a:hover{background:#2d323e;color:#fff}#left-box>ul>li>a svg{transition:all .25s;width:14px;height:14px}#left-box>ul>li+.active>ul{transition:all .25s;padding:.5rem 0;height:auto}#left-box>ul>li+.active>a{background:#2d323e}#left-box>ul>li+.active svg{transform:rotate(90deg)}#left-box>ul>li+.active .active>a{border-color:var(--primary)}#left-box>ul>li>ul{overflow:hidden;height:0;margin:0;padding:0;list-style-type:none}#left-box>ul>li>ul>li>a{display:block;line-height:2.25rem;padding:0 2rem;color:rgba(255,255,255,.85);border-left:5px solid transparent}#left-box>ul>li>ul>li>a:hover,#left-box>ul>li>ul>li>a:active{border-color:var(--primary);color:rgba(255,255,255,.95)}#right-box{flex:1;max-width:100%;box-sizing:border-box;position:relative;height:100vh;overflow-y:auto}#right-box::-webkit-scrollbar-track{background:transparent}#right-box::-webkit-scrollbar-thumb{background:rgba(0,0,0,.1);border-radius:6px}#right-box::-webkit-scrollbar-thumb:hover{background:rgba(0,0,0,.15)}#changelist .paginator{border:none !important;margin-top:1rem !important}.paginator a:link,.paginator a:visited{background-color:var(--primary) !important}.paginator a.showall{color:var(--primary) !important;background-color:transparent !important}#user-tools2{margin:0;padding:0}#user-tools2>li{display:inline-block;position:relative}#user-tools2>li>a{display:inline-block;margin-left:.5rem;padding:.5rem 1rem;border-radius:.25rem}#user-tools2>li:hover>a{background-color:rgba(77,89,149,.06);color:var(--primary)}#user-tools2>li>ul{display:none;position:absolute;top:2rem;right:0;background-color:var(--white);box-shadow:1px 2px var(--light);margin:0;padding:0;list-style-type:none;border-radius:.25rem;z-index:9999}#user-tools2>li>ul>li{display:block;border-bottom:1px solid rgba(0,0,0,.12)}#user-tools2>li>ul>li:last-child{border-bottom:none !important}#user-tools2>li>ul>li>a{display:block;padding:.5rem 1.5rem;white-space:nowrap}#user-tools2>li:hover>ul{display:inline-block !important}#changelist-filter{z-index:auto !important;padding:.5rem !important;background-color:var(--light) !important;white-space:nowrap;overflow-x:auto;width:100%;box-sizing:border-box}#changelist-filter::-webkit-scrollbar{display:none}.juss-filter{display:inline-block;margin:0 .5rem 0 0}#content{position:relative;margin-top:3.5rem;padding:0}#content #inner>p{margin:0;padding:.5rem 1rem;background-color:#fff}#content #inner>p:first-child{padding-top:1rem;border-radius:.25rem .25rem 0 0}#content #inner>p:last-child{padding-bottom:1rem;border-radius:0 0 .25rem .25rem}#content #content-main{float:initial;flex:1;padding:1rem;box-sizing:border-box;background-color:#fff;border-radius:.25rem}#content #content-main .object-tools{position:absolute;top:4.75rem;right:1.5rem;display:block;white-space:nowrap;overflow-x:auto;z-index:8;float:initial;text-align:right;height:auto}#content #content-main .object-tools::webkit-scrollbar{display:none}#content #content-main .object-tools li{display:inline-block;float:initial;height:auto}#content #content-main .object-tools li a{display:inline-block !important;float:initial !important;background-color:transparent;border:1px solid #e1e1ef !important}#content #content-main .object-tools li a:focus,#content #content-main .object-tools li a:hover{background-color:#e1e1ef !important;color:#5867dd;border-color:transparent !important}@media(max-width: 768px){#content{margin-top:3rem;overflow-x:hidden}#content>h1,#content #inner,#content #footer{width:100vw;max-width:100vw;box-sizing:border-box}#content .object-tools a{background-color:#e1e1ef;border:none}}/*# sourceMappingURL=base.css.map */
