{% load static %}
{% comment %}<textarea name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html" %}>
  {% if widget.value %}{{ widget.value }}{% endif %}</textarea>{% endcomment %}
<div id="id_{{widget.name}}" style="float:left;width:100%;">
</div>
<script>
  window.props = {
    id: "id_{{widget.name}}",
    name: "{{widget.name}}",
    init: {{widget.attrs.template|safe}},
    value: {% if widget.value %}{{widget.value|safe }}{% endif %}
  }
</script>
<script src="{% static "juss/jsoninput.bundle.js" %}"></script>
