{% load static %}
<div id="id_{{widget.name}}" style="float:left;width:calc(100% - 180px)">
</div>
<script>
  window.props = {
    id: "id_{{widget.name}}",
    name: "{{widget.name}}",
    value: "{% if widget.value %}{{widget.value}}{% endif %}"
  }
</script>
<script src="{% static "juss/mulimage.bundle.js" %}"></script>
