{% load i18n static %}<!DOCTYPE html>
<html lang="zh-hans">
<head>
<title>{% block title %}{% endblock %}</title>
<link rel="stylesheet" type="text/css" href="{% block stylesheet %}{% static "admin/css/base.css" %}{% endblock %}">
<link rel="stylesheet" type="text/css" href="{% static "juss/base.css" %}">
<link rel="stylesheet" type="text/css" href="{% static "juss/juss.css" %}">
<script src="https://cdn.bootcss.com/feather-icons/4.24.1/feather.min.js"></script>
{% block extrastyle %}{% endblock %}
{% if LANGUAGE_BIDI %}<link rel="stylesheet" type="text/css" href="{% block stylesheet_rtl %}{% static "admin/css/rtl.css" %}{% endblock %}">{% endif %}
{% block extrahead %}{% endblock %}
{% block responsive %}
    <meta name="viewport" content="user-scalable=no, width=device-width, initial-scale=1.0, maximum-scale=1.0">
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/responsive.css" %}">
    {% if LANGUAGE_BIDI %}<link rel="stylesheet" type="text/css" href="{% static "admin/css/responsive_rtl.css" %}">{% endif %}
{% endblock %}
{% block blockbots %}<meta name="robots" content="NONE,NOARCHIVE">{% endblock %}
</head>
{% load i18n %}

<body class="{% if is_popup %}popup {% endif %}{% block bodyclass %}{% endblock %}"
  data-admin-utc-offset="{% now "Z" %}">

<!-- Container -->
<div id="container">

    {% if not is_popup %}
    <div id="left-box">
        <div id="left-box__header">
            <h1>{{site_title}}</h1>
        </div>
        <ul>
            <li style="display:none;"></li>
            {% for i in juss_left_menu %}
            <li {% for ii in i.children %}{% if ii.active %}class="active"{% endif %}{% endfor %}>
                <a href="javascript:;">{{i.label}}
                    <i data-feather="chevron-right"></i>
                </a>
                <ul>
                {% for ii in i.children %}
                <li {% if ii.active %}class="active"{% endif %}>
                    <a href="{{ii.path}}">{{ii.label}}</a>
                </li>
                {% endfor %}
                </ul>
            </li>
            {% endfor %}
        </ul>
        {% comment %}
        <dl>
            {% for i in juss_left_menu %}
            <dt>{{i.label}} <i data-feather="chevron-down"></i></dt>
            {% for ii in i.children %}
            <dd {% if ii.active %}class="active"{% endif %}><a href="{{ii.path}}">{{ii.label}}</a></dd>
            {% endfor %}
            {% endfor %}
        </dl>
        {% endcomment %}
    </div>
    <div id="right-box">
    {% endif %}

    {% if not is_popup %}
    <!-- Header -->

    <div id="header2">
      <div class="header__left">
        <a id="left_toggle" href="#"><i data-feather="menu"></i></a>
        <div class="breadcrumbs">
        {% block breadcrumbs %}
        <a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
        {% if title %}&rsaquo; {{ title }}{% endif %}
        {% endblock %}
        </div>
      </div>
      <ul id="user-tools2">
          {% if site_url %}<li><a href="{{ site_url }}">{% trans 'View site' %}</a></li>{% endif %}
        <li>
            <a href="#">Hi,  {% firstof user.get_short_name user.get_username %}</a>
            <ul>
                <li><a href="{% url 'admin:password_change' %}">{% trans 'Change password' %}</a></li>
                <li><a href="{% url 'admin:logout' %}">{% trans 'Log out' %}</a></li>
            </ul>
        </li>
    </ul>

    </div>

    {% endif %}

    <!-- Content -->
    <div id="content" class="{% block coltype %}colM{% endblock %}">
        {% block pretitle %}{% endblock %}
        {% block content_title %}{% if title %}<h1>{{ title }}</h1>{% endif %}{% endblock %}

        <div id="inner">
    {% block messages %}
        {% if messages %}
        <ul class="messagelist">{% for message in messages %}
          <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message|capfirst }}</li>
        {% endfor %}</ul>
        {% endif %}
    {% endblock messages %}

        {% block content %}
        {% block object-tools %}{% endblock %}
        {{ content }}
        {% endblock %}
        {% block sidebar %}{% endblock %}
        </div>
        <br class="clear">
    </div>
    <!-- END Content -->

    {% if not is_popup %}
    {% block footer %}<div id="footer"></div>{% endblock %}
    {% endif %}
</div>
</div>
<!-- END Container -->
<script src="{% static "bower_components/js-cookie/src/js.cookie.js" %}"></script>
<script src="{% static "juss/juss.js" %}"></script>
<script>
  feather.replace()
</script>

</body>
</html>
